import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { AddLineItemsToDraftOrderOptions, AddLineItemsToDraftOrderResponse, CommitDraftOrderOptions, CommitDraftOrderResponse, CreateCustomAdditionalFeesOptions, CreateCustomAdditionalFeesResponse, CreateCustomDiscountsOptions, CreateCustomDiscountsResponse, CreateDraftOrderResponse, CreateEmptyDraftOrderResponse, CreateOrderFromDraftOptions, CreateOrderFromDraftResponse, DeleteCustomAdditionalFeesResponse, DeleteCustomDiscountsResponse, DraftOrderCreatedEnvelope, DraftOrderDeletedEnvelope, DraftOrderUpdatedEnvelope, DraftOrdersQueryBuilder, GetDraftOrderResponse, GetOrderDraftabilityStatusResponse, IdAndApplied, LineItemChangeDetails, SetAdditionalFeesResponse, SetBillingInfoOptions, SetBillingInfoResponse, SetBusinessLocationOptions, SetBusinessLocationResponse, SetBuyerInfoOptions, SetBuyerInfoResponse, SetDiscountsResponse, SetRecipientInfoOptions, SetRecipientInfoResponse, SetShippingInfoOptions, SetShippingInfoResponse, SetTaxExemptionOptions, SetTaxExemptionResponse, UpdateExtendedFieldsOptions, UpdateExtendedFieldsResponse, UpdateLineItemsResponse } from './ecom-v1-draft-order-draft-orders.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createDraftOrder(httpClient: HttpClient): CreateDraftOrderSignature;
interface CreateDraftOrderSignature {
    /**
     * Creates or retrieves a draft order based on the specified order ID.
     *
     * When passing the ID of an order that is already in draft, the existing draft order is returned.
     * To complete a draft and update the original order, call Commit Draft Order.
     * @param - ID of the order to create a draft for.
     */
    (orderId: string): Promise<CreateDraftOrderResponse>;
}
export declare function createEmptyDraftOrder(httpClient: HttpClient): CreateEmptyDraftOrderSignature;
interface CreateEmptyDraftOrderSignature {
    /**
     * Creates an empty draft order.
     *
     * After all relevant details are applied, call Create Order From Draft to convert the draft order to a regular order.
     */
    (): Promise<CreateEmptyDraftOrderResponse>;
}
export declare function addLineItemsToDraftOrder(httpClient: HttpClient): AddLineItemsToDraftOrderSignature;
interface AddLineItemsToDraftOrderSignature {
    /**
     * Adds catalog or custom line items to a draft order.
     * @param - Draft order ID.
     */
    (draftOrderId: string, options?: AddLineItemsToDraftOrderOptions | undefined): Promise<AddLineItemsToDraftOrderResponse>;
}
export declare function updateLineItems(httpClient: HttpClient): UpdateLineItemsSignature;
interface UpdateLineItemsSignature {
    /**
     * Updates a draft order's line items.
     *
     * You can update a line item's quantity, price, and description.
     * > **Notes:**
     * > + Specifying a quantity of `0` will remove the line item.
     * > + Price cannot be updated for line items with `paymentOption: MEMBERSHIP`.
     * > + Quantity cannot be decreased for fulfilled line items. To retrieve fulfillment information, specify the order ID when calling List Fulfillments For Single Order ([SDK](https://dev.wix.com/docs/sdk/backend-modules/ecom/order-fulfillments/list-fulfillments-for-single-order) | [REST](https://dev.wix.com/docs/rest/business-solutions/e-commerce/orders/order-fulfillments/list-fulfillments-for-single-order)).
     * @param - Draft order ID.
     * @param - Details of changes to apply per line item.
     */
    (draftOrderId: string, lineItemChanges: LineItemChangeDetails[]): Promise<UpdateLineItemsResponse>;
}
export declare function setDiscounts(httpClient: HttpClient): SetDiscountsSignature;
interface SetDiscountsSignature {
    /**
     * Applies or unapplies discounts on a draft order.
     *
     * Unapplied discounts are still part of the draft order, but do not affect balance.
     * Existing discounts that are not passed in the request will keep their current state.
     * @param - Draft order ID.
     * @param - Discounts to set on the draft order.
     *
     * Any existing discounts that are not passed will not change.
     */
    (draftOrderId: string, discounts: IdAndApplied[]): Promise<SetDiscountsResponse>;
}
export declare function createCustomDiscounts(httpClient: HttpClient): CreateCustomDiscountsSignature;
interface CreateCustomDiscountsSignature {
    /**
     * Creates custom discounts.
     *
     * Newly created discounts are unapplied by default.
     * To apply them, use Set Discounts.
     * @param - Draft order ID.
     */
    (draftOrderId: string, options?: CreateCustomDiscountsOptions | undefined): Promise<CreateCustomDiscountsResponse>;
}
export declare function deleteCustomDiscounts(httpClient: HttpClient): DeleteCustomDiscountsSignature;
interface DeleteCustomDiscountsSignature {
    /**
     * Removes custom discounts from a draft order.
     * @param - Draft order ID.
     * @param - IDs of the discounts to remove from the draft order.
     */
    (draftOrderId: string, discountIds: string[]): Promise<DeleteCustomDiscountsResponse>;
}
export declare function setAdditionalFees(httpClient: HttpClient): SetAdditionalFeesSignature;
interface SetAdditionalFeesSignature {
    /**
     * Applies or unapplies additional fees on a draft order.
     *
     * Additional fees that are not applied are still part of the draft order, but do not affect balance.
     * Existing additional fees that are not passed in the request will keep their current state.
     * @param - Draft order ID.
     * @param - Additional fees to set on the draft order.
     *
     * Any existing additional fees that are not passed will not change.
     */
    (draftOrderId: string, additionalFees: IdAndApplied[]): Promise<SetAdditionalFeesResponse>;
}
export declare function createCustomAdditionalFees(httpClient: HttpClient): CreateCustomAdditionalFeesSignature;
interface CreateCustomAdditionalFeesSignature {
    /**
     * Creates custom additional fees on a draft order.
     *
     * Newly created additional fees are not applied by default.
     * To apply them, use Set Additional Fees.
     * @param - Draft order ID.
     */
    (draftOrderId: string, options?: CreateCustomAdditionalFeesOptions | undefined): Promise<CreateCustomAdditionalFeesResponse>;
}
export declare function deleteCustomAdditionalFees(httpClient: HttpClient): DeleteCustomAdditionalFeesSignature;
interface DeleteCustomAdditionalFeesSignature {
    /**
     * Removes custom additional fees from a draft order.
     * @param - Draft order ID.
     * @param - IDs of the additional fees to remove from the draft order.
     */
    (draftOrderId: string, customAdditionalFees: string[]): Promise<DeleteCustomAdditionalFeesResponse>;
}
export declare function setShippingInfo(httpClient: HttpClient): SetShippingInfoSignature;
interface SetShippingInfoSignature {
    /**
     * Sets shipping information on a draft order.
     * @param - Draft order ID.
     */
    (draftOrderId: string, options?: SetShippingInfoOptions | undefined): Promise<SetShippingInfoResponse>;
}
export declare function setBuyerInfo(httpClient: HttpClient): SetBuyerInfoSignature;
interface SetBuyerInfoSignature {
    /**
     * Sets buyer info on a draft order.
     * @param - Draft order ID.
     */
    (draftOrderId: string, options?: SetBuyerInfoOptions | undefined): Promise<SetBuyerInfoResponse>;
}
export declare function setRecipientInfo(httpClient: HttpClient): SetRecipientInfoSignature;
interface SetRecipientInfoSignature {
    /**
     * Sets recipient info on a draft order.
     * @param - Draft order ID.
     */
    (draftOrderId: string, options?: SetRecipientInfoOptions | undefined): Promise<SetRecipientInfoResponse>;
}
export declare function setBillingInfo(httpClient: HttpClient): SetBillingInfoSignature;
interface SetBillingInfoSignature {
    /**
     * Sets billing info on a draft order.
     * @param - Draft order ID.
     */
    (draftOrderId: string, options?: SetBillingInfoOptions | undefined): Promise<SetBillingInfoResponse>;
}
export declare function getDraftOrder(httpClient: HttpClient): GetDraftOrderSignature;
interface GetDraftOrderSignature {
    /**
     * Retrieves a draft order.
     *
     * The retrieved draft order contains the latest calculations:
     * + Line items, shipping details, and buyer information.
     * + Tax details and price totals.
     * + Automatic discounts and automatic additional fees, along with updated eligibility.
     *
     * > **Note:** When retrieving a committed draft order, it **is not recalculated**.
     * @param - Draft order ID.
     */
    (draftOrderId: string): Promise<GetDraftOrderResponse>;
}
export declare function getOrderDraftabilityStatus(httpClient: HttpClient): GetOrderDraftabilityStatusSignature;
interface GetOrderDraftabilityStatusSignature {
    /**
     * Checks whether a draft can be created for an order.
     *
     * If `orderDraftable` returns as `true`, the order can be used to create a draft order.
     *
     * If `orderDraftable` returns as `false`, refer to the `nonDraftableReasons` array in the response to understand why the order is not draftable.
     * @param - Order ID.
     */
    (orderId: string): Promise<GetOrderDraftabilityStatusResponse>;
}
export declare function commitDraftOrder(httpClient: HttpClient): CommitDraftOrderSignature;
interface CommitDraftOrderSignature {
    /**
     * Finalizes a draft order and applies its modifications to the associated order.
     * You can also control which side-effects are executed on commit.
     *
     * > **Notes:**
     * > + The draft order's status is set to `COMMITTED`.
     * > + Commiting a draft order cannot be undone or reverted.
     * > + A committed draft order does not allow for further modifications. However, it is kept for reference and can be retrieved.
     * @param - Draft order ID.
     */
    (draftOrderId: string, options?: CommitDraftOrderOptions | undefined): Promise<CommitDraftOrderResponse>;
}
export declare function createOrderFromDraft(httpClient: HttpClient): CreateOrderFromDraftSignature;
interface CreateOrderFromDraftSignature {
    /**
     * Creates a new order from a draft, while specifying which side-effects are executed.
     *
     * > **Notes:**
     * > + The draft order's status is set to `COMMITTED`.
     * > + Commiting a draft order cannot be undone or reverted.
     * > + A committed draft order does not allow for further modifications. However, it is kept for reference and can be retrieved.
     * @param - Draft order ID.
     */
    (draftOrderId: string, options?: CreateOrderFromDraftOptions | undefined): Promise<CreateOrderFromDraftResponse>;
}
export declare function deleteDraftOrder(httpClient: HttpClient): DeleteDraftOrderSignature;
interface DeleteDraftOrderSignature {
    /**
     * Deletes a draft order along with all its pending changes.
     *
     * Draft orders with status 'COMMITTED' cannot be deleted.
     * @param - Draft order ID.
     */
    (draftOrderId: string): Promise<void>;
}
export declare function queryDraftOrders(httpClient: HttpClient): QueryDraftOrdersSignature;
interface QueryDraftOrdersSignature {
    /**
     * Retrieves a list of up to 100 draft orders, given the provided paging, filtering, and sorting.
     *
     * For field support, see [supported filters and sorting](https://dev.wix.com/docs/rest/business-solutions/e-commerce/orders/draft-orders/supported-filters-and-sorting).
     * To learn how to query draft orders, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language).
     */
    (): DraftOrdersQueryBuilder;
}
export declare function updateExtendedFields(httpClient: HttpClient): UpdateExtendedFieldsSignature;
interface UpdateExtendedFieldsSignature {
    /**
     * Updates extended fields on a draft order.
     * @param - ID of the entity to update.
     * @param - Identifier for the app whose extended fields are being updated.
     */
    (_id: string, namespace: string, options: UpdateExtendedFieldsOptions): Promise<UpdateExtendedFieldsResponse>;
}
export declare function setTaxExemption(httpClient: HttpClient): SetTaxExemptionSignature;
interface SetTaxExemptionSignature {
    /**
     * Sets whether a draft order is tax-exempt.
     *
     * A tax exempted draft order ignores taxes during calculation. Tax information will return empty.
     * @param - Draft order ID.
     */
    (draftOrderId: string, options: SetTaxExemptionOptions): Promise<SetTaxExemptionResponse>;
}
export declare function setBusinessLocation(httpClient: HttpClient): SetBusinessLocationSignature;
interface SetBusinessLocationSignature {
    /**
     * Sets business location on a draft order.
     *
     * When committed, the order will become associated to a specific business location. This affects who can see and manage this order, and how it is calculated in reports.
     * @param - Draft order ID.
     */
    (draftOrderId: string, options?: SetBusinessLocationOptions | undefined): Promise<SetBusinessLocationResponse>;
}
export declare const onDraftOrderCreated: EventDefinition<DraftOrderCreatedEnvelope, "wix.ecom.v1.draft_order_created">;
export declare const onDraftOrderDeleted: EventDefinition<DraftOrderDeletedEnvelope, "wix.ecom.v1.draft_order_deleted">;
export declare const onDraftOrderUpdated: EventDefinition<DraftOrderUpdatedEnvelope, "wix.ecom.v1.draft_order_updated">;
export { ActionEvent, Activity, ActivityContentOneOf, ActivityType, AddLineItemsToDraftOrderOptions, AddLineItemsToDraftOrderRequest, AddLineItemsToDraftOrderResponse, AdditionalFee, AdditionalFeeDetails, AdditionalFeeOption, Address, AddressLocation, AddressWithContact, AdjustmentType, ApplicationError, AppliedDiscount, AppliedDiscountDiscountSourceOneOf, AppliedDiscountDiscountType, AttributionSource, AuthorizedPaymentCaptured, AuthorizedPaymentCreated, AuthorizedPaymentVoided, Balance, BalanceSummary, BaseEventMetadata, BillingAdjustment, BillingAdjustmentPriceSummary, BillingChangedDetails, BillingDetails, BillingDetailsChangeTypeOneOf, BusinessLocationChangedDetails, BusinessLocationDetails, BusinessLocationDetailsChangeTypeOneOf, BuyerChangedDetails, BuyerDetails, BuyerDetailsChangeTypeOneOf, BuyerInfo, BuyerInfoIdOneOf, CalculatedDraftOrder, CalculationErrors, CalculationErrorsShippingCalculationErrorOneOf, CarrierError, CarrierErrors, CatalogReference, CatalogReferenceLineItem, ChannelInfo, ChannelType, Color, CommitDraftOrderOptions, CommitDraftOrderRequest, CommitDraftOrderResponse, Coupon, CreateCustomAdditionalFeesOptions, CreateCustomAdditionalFeesRequest, CreateCustomAdditionalFeesResponse, CreateCustomDiscountsOptions, CreateCustomDiscountsRequest, CreateCustomDiscountsResponse, CreateDraftOrderRequest, CreateDraftOrderResponse, CreateEmptyDraftOrderRequest, CreateEmptyDraftOrderResponse, CreateOrderFromDraftOptions, CreateOrderFromDraftRequest, CreateOrderFromDraftResponse, CreatedBy, CreatedByStringOneOf, CreditCardDetails, CurrencyConversionDetails, CursorPaging, CursorPagingMetadata, CursorQuery, CursorQueryPagingMethodOneOf, Cursors, CustomActivity, CustomField, CustomLineItem, DeleteCustomAdditionalFeesRequest, DeleteCustomAdditionalFeesResponse, DeleteCustomDiscountsRequest, DeleteCustomDiscountsResponse, DeleteDraftOrderRequest, DeleteDraftOrderResponse, DeliveryLogistics, DeliveryTimeSlot, DescriptionLine, DescriptionLineDescriptionLineValueOneOf, DescriptionLineName, DescriptionLineType, DescriptionLineValueOneOf, Details, DetailsKindOneOf, DigitalFile, DiscountDetails, DiscountOption, DiscountOptionDiscountAmountOneOf, DiscountReason, DiscountRule, DiscountRuleName, DiscountType, DomainEvent, DomainEventBodyOneOf, DraftOrder, DraftOrderChangesApplied, DraftOrderCommitSettings, DraftOrderCreatedEnvelope, DraftOrderDeletedEnvelope, DraftOrderUpdatedEnvelope, DraftOrdersQueryBuilder, DraftOrdersQueryResult, EditingStatus, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, ExtendedFields, ExternalReceipt, FieldViolation, FileType, FocalPoint, FreeTrialPeriod, FulfillmentStatus, FulfillmentStatusesAggregate, FullAddressContactDetails, GetDraftOrderRequest, GetDraftOrderResponse, GetOrderDraftabilityStatusRequest, GetOrderDraftabilityStatusResponse, GiftCardPaymentRefund, IdAndApplied, IdentificationData, IdentificationDataIdOneOf, InventoryUpdate, ItemChangedDetails, ItemDetails, ItemDetailsChangeTypeOneOf, ItemModifier, ItemTaxFullDetails, ItemType, ItemTypeItemType, ItemTypeItemTypeDataOneOf, JurisdictionType, LineItemAmount, LineItemChangeDetails, LineItemChanges, LineItemDiscount, LineItemExchangeData, LineItemPriceChange, LineItemQuantityChange, LineItemQuantityChangeType, LineItemTaxBreakdown, LineItemTaxInfo, Location, LocationAndQuantity, ManagedAdditionalFee, ManagedDiscount, ManagedLineItem, MembershipPaymentRefund, MerchantComment, MerchantDiscount, MerchantDiscountMerchantDiscountReasonOneOf, MessageEnvelope, ModifierGroup, NewExchangeOrderCreated, NonDraftableReason, Order, OrderChange, OrderChangeValueOneOf, OrderCreateNotifications, OrderCreateSettings, OrderCreatedFromExchange, OrderLineItem, OrderRefunded, OrderStatus, OrderTaxBreakdown, OrderTaxInfo, PaymentCanceled, PaymentCanceledPaymentDetailsOneOf, PaymentDeclined, PaymentDeclinedPaymentDetailsOneOf, PaymentOptionType, PaymentPending, PaymentPendingPaymentDetailsOneOf, PaymentRefundFailed, PaymentRefunded, PaymentStatus, PhysicalProperties, PickupAddress, PickupDetails, PickupDetailsPickupMethod, PickupMethod, PlainTextValue, Price, PriceDescription, PriceSummary, ProductName, QueryDraftOrdersRequest, QueryDraftOrdersResponse, ReceiptCreated, ReceiptCreatedReceiptInfoOneOf, ReceiptSent, ReceiptSentReceiptInfoOneOf, RecipientInfoChangedDetails, RecipientInfoDetails, RecipientInfoDetailsChangeTypeOneOf, RefundInitiated, RefundedAsStoreCredit, RefundedPayment, RefundedPaymentKindOneOf, RegularPayment, RegularPaymentPaymentMethodDetailsOneOf, RegularPaymentRefund, RestoreInfo, RuleType, SavedPaymentMethod, SecuredMedia, SetAdditionalFeesRequest, SetAdditionalFeesResponse, SetBillingInfoOptions, SetBillingInfoRequest, SetBillingInfoResponse, SetBusinessLocationOptions, SetBusinessLocationRequest, SetBusinessLocationResponse, SetBuyerInfoOptions, SetBuyerInfoRequest, SetBuyerInfoResponse, SetDiscountsRequest, SetDiscountsResponse, SetRecipientInfoOptions, SetRecipientInfoRequest, SetRecipientInfoResponse, SetShippingInfoOptions, SetShippingInfoRequest, SetShippingInfoResponse, SetTaxExemptionOptions, SetTaxExemptionRequest, SetTaxExemptionResponse, ShippingChangedDetails, ShippingDetails, ShippingDetailsChangeTypeOneOf, ShippingInformation, ShippingInformationChange, ShippingOption, ShippingPrice, ShippingRegion, SortOrder, Sorting, SourceType, StreetAddress, SubscriptionDescription, SubscriptionFrequency, SubscriptionInfo, SubscriptionSettings, SubscriptionTitle, SystemError, TagList, Tags, TaxDetails, TaxSummary, TaxableAddress, TaxableAddressTaxableAddressDataOneOf, TaxableAddressType, TotalPriceChange, TranslatableString, TranslatedValue, UpdateExtendedFieldsOptions, UpdateExtendedFieldsRequest, UpdateExtendedFieldsResponse, UpdateLineItemsRequest, UpdateLineItemsResponse, UpdateShippingInfoRequest, UpdateShippingInfoResponse, V1BalanceSummary, V1CreatedBy, V1CreatedByStringOneOf, V1DeliveryLogistics, V1DeliveryLogisticsAddressOneOf, V1DeliveryTimeSlot, V1PickupDetails, V1ShippingInformation, V1ShippingPrice, ValidationError, VatId, VatType, WebhookIdentityType, WeightUnit, WixReceipt, } from './ecom-v1-draft-order-draft-orders.universal.js';
