import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Creates or retrieves a draft order based on the specified order ID.
 *
 * When passing the ID of an order that is already in draft, the existing draft order is returned.
 * To complete a draft and update the original order, call Commit Draft Order.
 */
export declare function createDraftOrder(payload: object): RequestOptionsFactory<any>;
/**
 * Creates an empty draft order.
 *
 * After all relevant details are applied, call Create Order From Draft to convert the draft order to a regular order.
 */
export declare function createEmptyDraftOrder(payload: object): RequestOptionsFactory<any>;
/** Adds catalog or custom line items to a draft order. */
export declare function addLineItemsToDraftOrder(payload: object): RequestOptionsFactory<any>;
/**
 * Updates a draft order's line items.
 *
 * You can update a line item's quantity, price, and description.
 * > **Notes:**
 * > + Specifying a quantity of `0` will remove the line item.
 * > + Price cannot be updated for line items with `paymentOption: MEMBERSHIP`.
 * > + Quantity cannot be decreased for fulfilled line items. To retrieve fulfillment information, specify the order ID when calling List Fulfillments For Single Order ([SDK](https://dev.wix.com/docs/sdk/backend-modules/ecom/order-fulfillments/list-fulfillments-for-single-order) | [REST](https://dev.wix.com/docs/rest/business-solutions/e-commerce/orders/order-fulfillments/list-fulfillments-for-single-order)).
 */
export declare function updateLineItems(payload: object): RequestOptionsFactory<any>;
/**
 * Applies or unapplies discounts on a draft order.
 *
 * Unapplied discounts are still part of the draft order, but do not affect balance.
 * Existing discounts that are not passed in the request will keep their current state.
 */
export declare function setDiscounts(payload: object): RequestOptionsFactory<any>;
/**
 * Creates custom discounts.
 *
 * Newly created discounts are unapplied by default.
 * To apply them, use Set Discounts.
 */
export declare function createCustomDiscounts(payload: object): RequestOptionsFactory<any>;
/** Removes custom discounts from a draft order. */
export declare function deleteCustomDiscounts(payload: object): RequestOptionsFactory<any>;
/**
 * Applies or unapplies additional fees on a draft order.
 *
 * Additional fees that are not applied are still part of the draft order, but do not affect balance.
 * Existing additional fees that are not passed in the request will keep their current state.
 */
export declare function setAdditionalFees(payload: object): RequestOptionsFactory<any>;
/**
 * Creates custom additional fees on a draft order.
 *
 * Newly created additional fees are not applied by default.
 * To apply them, use Set Additional Fees.
 */
export declare function createCustomAdditionalFees(payload: object): RequestOptionsFactory<any>;
/** Removes custom additional fees from a draft order. */
export declare function deleteCustomAdditionalFees(payload: object): RequestOptionsFactory<any>;
/** Sets shipping information on a draft order. */
export declare function setShippingInfo(payload: object): RequestOptionsFactory<any>;
/** Sets buyer info on a draft order. */
export declare function setBuyerInfo(payload: object): RequestOptionsFactory<any>;
/** Sets recipient info on a draft order. */
export declare function setRecipientInfo(payload: object): RequestOptionsFactory<any>;
/** Sets billing info on a draft order. */
export declare function setBillingInfo(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves a draft order.
 *
 * The retrieved draft order contains the latest calculations:
 * + Line items, shipping details, and buyer information.
 * + Tax details and price totals.
 * + Automatic discounts and automatic additional fees, along with updated eligibility.
 *
 * > **Note:** When retrieving a committed draft order, it **is not recalculated**.
 */
export declare function getDraftOrder(payload: object): RequestOptionsFactory<any>;
/**
 * Checks whether a draft can be created for an order.
 *
 * If `orderDraftable` returns as `true`, the order can be used to create a draft order.
 *
 * If `orderDraftable` returns as `false`, refer to the `nonDraftableReasons` array in the response to understand why the order is not draftable.
 */
export declare function getOrderDraftabilityStatus(payload: object): RequestOptionsFactory<any>;
/**
 * Finalizes a draft order and applies its modifications to the associated order.
 * You can also control which side-effects are executed on commit.
 *
 * > **Notes:**
 * > + The draft order's status is set to `COMMITTED`.
 * > + Commiting a draft order cannot be undone or reverted.
 * > + A committed draft order does not allow for further modifications. However, it is kept for reference and can be retrieved.
 */
export declare function commitDraftOrder(payload: object): RequestOptionsFactory<any>;
/**
 * Creates a new order from a draft, while specifying which side-effects are executed.
 *
 * > **Notes:**
 * > + The draft order's status is set to `COMMITTED`.
 * > + Commiting a draft order cannot be undone or reverted.
 * > + A committed draft order does not allow for further modifications. However, it is kept for reference and can be retrieved.
 */
export declare function createOrderFromDraft(payload: object): RequestOptionsFactory<any>;
/**
 * Deletes a draft order along with all its pending changes.
 *
 * Draft orders with status 'COMMITTED' cannot be deleted.
 */
export declare function deleteDraftOrder(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves a list of up to 100 draft orders, given the provided paging, filtering, and sorting.
 *
 * For field support, see [supported filters and sorting](https://dev.wix.com/docs/rest/business-solutions/e-commerce/orders/draft-orders/supported-filters-and-sorting).
 * To learn how to query draft orders, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language).
 */
export declare function queryDraftOrders(payload: object): RequestOptionsFactory<any>;
/** Updates extended fields on a draft order. */
export declare function updateExtendedFields(payload: object): RequestOptionsFactory<any>;
/**
 * Sets whether a draft order is tax-exempt.
 *
 * A tax exempted draft order ignores taxes during calculation. Tax information will return empty.
 */
export declare function setTaxExemption(payload: object): RequestOptionsFactory<any>;
/**
 * Sets business location on a draft order.
 *
 * When committed, the order will become associated to a specific business location. This affects who can see and manage this order, and how it is calculated in reports.
 */
export declare function setBusinessLocation(payload: object): RequestOptionsFactory<any>;
